searchData={"items":[{"type":"module","title":"Tint","doc":"A library allowing calculations with colors and conversions between different\ncolorspaces.","ref":"Tint.html"},{"type":"function","title":"Tint.convert/2","doc":"Converts the given color to another colorspace.","ref":"Tint.html#convert/2"},{"type":"function","title":"Examples - Tint.convert/2","doc":"iex> Tint.convert(Tint.RGB.new(40, 66, 67), :cmyk)\n    {:ok, %Tint.CMYK{cyan: 0.403, magenta: 0.0149, yellow: 0.0, key: 0.7373}}\n\n    iex> Tint.convert(Tint.RGB.new(255, 127, 30), Tint.HSV)\n    {:ok, %Tint.HSV{hue: 25.9, saturation: 0.8824, value: 1.0}}\n\n    iex> Tint.convert(Tint.RGB.new(255, 127, 30), :invalid)\n    :error","ref":"Tint.html#convert/2-examples"},{"type":"function","title":"Tint.convert!/2","doc":"Converts the given color to another colorspace. Raises when the colorspace\nis invalid.","ref":"Tint.html#convert!/2"},{"type":"function","title":"Examples - Tint.convert!/2","doc":"iex> Tint.convert!(Tint.RGB.new(40, 66, 67), :cmyk)\n    %Tint.CMYK{cyan: 0.403, magenta: 0.0149, yellow: 0.0, key: 0.7373}\n\n    iex> Tint.convert!(Tint.RGB.new(255, 127, 30), Tint.HSV)\n    %Tint.HSV{hue: 25.9, saturation: 0.8824, value: 1.0}\n\n    iex> Tint.convert!(Tint.RGB.new(255, 127, 30), :foo)\n    ** (ArgumentError) Unknown colorspace: :foo","ref":"Tint.html#convert!/2-examples"},{"type":"function","title":"Tint.converter_for/1","doc":"Gets the converter module for the given colorspace atom or module.","ref":"Tint.html#converter_for/1"},{"type":"function","title":"Tint.to_cmyk/1","doc":"Converts the given color to the CMYK colorspace.","ref":"Tint.html#to_cmyk/1"},{"type":"function","title":"Example - Tint.to_cmyk/1","doc":"iex> Tint.to_cmyk(Tint.RGB.new(40, 66, 67))\n    #Tint.CMYK<40.3%,1.49%,0.0%,73.73%>","ref":"Tint.html#to_cmyk/1-example"},{"type":"function","title":"Tint.to_din99/1","doc":"Converts the given color to the DIN99 colorspace.","ref":"Tint.html#to_din99/1"},{"type":"function","title":"Tint.to_hsv/1","doc":"Converts the given color to the HSV colorspace.","ref":"Tint.html#to_hsv/1"},{"type":"function","title":"Example - Tint.to_hsv/1","doc":"iex> Tint.to_hsv(Tint.RGB.new(255, 127, 30))\n    #Tint.HSV<25.9°,88.24%,100.0%>","ref":"Tint.html#to_hsv/1-example"},{"type":"function","title":"Tint.to_lab/1","doc":"Converts the given color to the CIELAB colorspace.","ref":"Tint.html#to_lab/1"},{"type":"function","title":"Tint.to_rgb/1","doc":"Converts the given color to the RGB colorspace.","ref":"Tint.html#to_rgb/1"},{"type":"function","title":"Example - Tint.to_rgb/1","doc":"iex> Tint.to_rgb(Tint.HSV.new(25.8, 0.882, 1))\n    #Tint.RGB<255,127,30 (#FF7F1E)>","ref":"Tint.html#to_rgb/1-example"},{"type":"function","title":"Tint.to_xyz/1","doc":"Converts the given color to the XYZ (CIE 1931) colorspace.","ref":"Tint.html#to_xyz/1"},{"type":"type","title":"Tint.color/0","doc":"A type representing a color.","ref":"Tint.html#t:color/0"},{"type":"type","title":"Tint.colorspace/0","doc":"A type representing a colorspace.","ref":"Tint.html#t:colorspace/0"},{"type":"module","title":"Tint.Sigil","doc":"A module providing a sigil to build colors.","ref":"Tint.Sigil.html"},{"type":"function","title":"Tint.Sigil.sigil_K/2","doc":"A sigil to build a color.\n\nThe sigil identifier is `K` (try using \"kolor\" as mnemonic) because `C` is\nalready taken by the built-in charlist sigil.","ref":"Tint.Sigil.html#sigil_K/2"},{"type":"function","title":"Examples - Tint.Sigil.sigil_K/2","doc":"First you need to import this particular module.\n\n    import Tint.Sigil\n\nYou can build a RGB color using a hex code, just like `Tint.RGB.from_hex/1`\ndoes:\n\n    iex> ~K[#FFCC00]\n    #Tint.RGB<255,204,0 (#FFCC00)>\n\nOr using the red, green and blue components using the `r` modifier.\n\n    iex> ~K[255,204,0]r\n    #Tint.RGB<255,204,0 (#FFCC00)>\n\nHSV colors are also supported using the `h` modifier.\n\n    iex> ~K[48,1,1]h\n    #Tint.HSV<48.0°,100.0%,100.0%>\n\nCMYK colors are supported using the `c` modifier.\n\n    iex> ~K[0.06, 0.32, 0.8846, 0.23]c\n    #Tint.CMYK<6.0%,32.0%,88.46%,23.0%>\n\nCIELAB colors are supported using the `l` modifier.\n\n    iex> ~K[50.1234,10.7643,10.4322]l\n    #Tint.Lab<50.1234,10.7643,10.4322>\n\nDIN99 colors are supported using the `d` modifier.\n\n    iex> ~K[50.1234,10.7643,10.4322]d\n    #Tint.DIN99<50.1234,10.7643,10.4322>\n\nXYZ colors are supported using the `x` modifier.\n\n    iex> ~K[50.9505,1,1.09]x\n    #Tint.XYZ<50.9505,1.0,1.09>","ref":"Tint.Sigil.html#sigil_K/2-examples"},{"type":"module","title":"Tint.CMYK","doc":"A color in the CMYK (cyan, magenta, yellow, key) colorspace.","ref":"Tint.CMYK.html"},{"type":"function","title":"Tint.CMYK.from_tuple/1","doc":"Converts a tuple containing cyan, magenta, yellow and key color parts into a\n`Tint.CMYK` struct.","ref":"Tint.CMYK.html#from_tuple/1"},{"type":"function","title":"Tint.CMYK.new/4","doc":"Builds a new CMYK color from cyan, magenta, yellow and key color parts. Please\nalways use this function to build a new CMYK color.","ref":"Tint.CMYK.html#new/4"},{"type":"function","title":"Examples - Tint.CMYK.new/4","doc":"iex> Tint.CMYK.new(0.06, 0.32, 0.8846, 0.23)\n    #Tint.CMYK<6.0%,32.0%,88.46%,23.0%>\n\n    iex> Tint.CMYK.new(0.06, 3.2, 0.8846, 0.23)\n    ** (Tint.OutOfRangeError) Value 3.2 is out of range [0,1]","ref":"Tint.CMYK.html#new/4-examples"},{"type":"function","title":"Tint.CMYK.to_tuple/1","doc":"Converts CMYK color into a tuple containing the cyan, magenta, yellow and key\nparts.","ref":"Tint.CMYK.html#to_tuple/1"},{"type":"type","title":"Tint.CMYK.t/0","doc":"","ref":"Tint.CMYK.html#t:t/0"},{"type":"module","title":"Tint.DIN99","doc":"A color in the DIN99 colorspace.","ref":"Tint.DIN99.html"},{"type":"function","title":"Tint.DIN99.from_tuple/1","doc":"Converts a tuple containing lightness, a and b into `Tint.DIN99` struct.","ref":"Tint.DIN99.html#from_tuple/1"},{"type":"function","title":"Tint.DIN99.new/3","doc":"Builds a new DIN99 color using the lightness, a and b color channels.","ref":"Tint.DIN99.html#new/3"},{"type":"function","title":"Tint.DIN99.to_tuple/1","doc":"Converts a DIN99 color into a tuple containing the lightness, a and b\nchannels.","ref":"Tint.DIN99.html#to_tuple/1"},{"type":"type","title":"Tint.DIN99.t/0","doc":"","ref":"Tint.DIN99.html#t:t/0"},{"type":"module","title":"Tint.HSV","doc":"A color in the HSV (hue, saturation, value) colorspace.","ref":"Tint.HSV.html"},{"type":"function","title":"Tint.HSV.from_tuple/1","doc":"Converts a tuple containing hue, saturation and value into a `Tint.HSV`\nstruct.","ref":"Tint.HSV.html#from_tuple/1"},{"type":"function","title":"Tint.HSV.grayscale?/1","doc":"Determines whether the given color is a grayscale color which basically means\nthat saturation or the value is 0.","ref":"Tint.HSV.html#grayscale?/1"},{"type":"function","title":"Tint.HSV.hue_between?/3","doc":"Checks whether the hue of the given color is in the specified bounds. This\ncan be used to cluster colors by their chromaticity.","ref":"Tint.HSV.html#hue_between?/3"},{"type":"function","title":"Tint.HSV.new/3","doc":"Builds a new HSV color from hue, saturation and value color parts. Please\nalways use this function to build a new HSV color.","ref":"Tint.HSV.html#new/3"},{"type":"function","title":"Examples - Tint.HSV.new/3","doc":"iex> Tint.HSV.new(25.8, 0.882, 1)\n    #Tint.HSV<25.8°,88.2%,100%>","ref":"Tint.HSV.html#new/3-examples"},{"type":"function","title":"Tint.HSV.to_tuple/1","doc":"Converts HSV color into a tuple containing the hue, saturation and value\nparts.","ref":"Tint.HSV.html#to_tuple/1"},{"type":"type","title":"Tint.HSV.t/0","doc":"","ref":"Tint.HSV.html#t:t/0"},{"type":"module","title":"Tint.Lab","doc":"A color in the CIELAB colorspace.","ref":"Tint.Lab.html"},{"type":"function","title":"Tint.Lab.ciede2000_distance/3","doc":"Calculates the distance of two colors using the CIEDE2000 algorithm. See\n`Tint.Distance.CIEDE2000` for more details.","ref":"Tint.Lab.html#ciede2000_distance/3"},{"type":"function","title":"Tint.Lab.from_tuple/1","doc":"Converts a tuple containing lightness, a and b into `Tint.Lab` struct.","ref":"Tint.Lab.html#from_tuple/1"},{"type":"function","title":"Tint.Lab.nearest_color/3","doc":"Gets the nearest color from the given palette using the CIEDE2000 color\ndistance algorithm.","ref":"Tint.Lab.html#nearest_color/3"},{"type":"function","title":"Options - Tint.Lab.nearest_color/3","doc":"* `:weights` - A tuple defining the weights for the LCh color channels.\n  Defaults to `{1, 1, 1}`.","ref":"Tint.Lab.html#nearest_color/3-options"},{"type":"function","title":"Tint.Lab.nearest_colors/4","doc":"Gets the n nearest colors from the given palette using the CIEDE2000 color\ndistance algorithm.","ref":"Tint.Lab.html#nearest_colors/4"},{"type":"function","title":"Tint.Lab.new/3","doc":"Builds a new Lab color using the lightness, a and b color channels.","ref":"Tint.Lab.html#new/3"},{"type":"function","title":"Tint.Lab.to_tuple/1","doc":"Converts a Lab color into a tuple containing the lightness, a and b channels.","ref":"Tint.Lab.html#to_tuple/1"},{"type":"type","title":"Tint.Lab.t/0","doc":"","ref":"Tint.Lab.html#t:t/0"},{"type":"module","title":"Tint.RGB","doc":"A color in the RGB (red, green, blue) colorspace.","ref":"Tint.RGB.html"},{"type":"function","title":"Tint.RGB.complementary_color/1","doc":"Calculates the complementary of the given RGB color.","ref":"Tint.RGB.html#complementary_color/1"},{"type":"function","title":"Example - Tint.RGB.complementary_color/1","doc":"iex> Tint.RGB.complementary_color(%Tint.RGB{red: 255, green: 0, blue: 0})\n    #Tint.RGB<0,255,255 (#00FFFF)>","ref":"Tint.RGB.html#complementary_color/1-example"},{"type":"function","title":"Tint.RGB.euclidean_distance/3","doc":"Calculates the Euclidean distance of two colors.","ref":"Tint.RGB.html#euclidean_distance/3"},{"type":"function","title":"Options - Tint.RGB.euclidean_distance/3","doc":"* `:weights` - A tuple defining the weights for the red, green and blue color\n  channels. Defaults to `{1, 1, 1}`.","ref":"Tint.RGB.html#euclidean_distance/3-options"},{"type":"function","title":"Tint.RGB.from_hex/1","doc":"Builds a new RGB color from the given hex code.","ref":"Tint.RGB.html#from_hex/1"},{"type":"function","title":"Examples - Tint.RGB.from_hex/1","doc":"iex> Tint.RGB.from_hex(\"#FF7F1E\")\n    {:ok, %Tint.RGB{red: 255, green: 127, blue: 30}}\n\n    iex> Tint.RGB.from_hex(\"F00\")\n    {:ok, %Tint.RGB{red: 255, green: 0, blue: 0}}\n\n    iex> Tint.RGB.from_hex(\"invalid\")\n    :error","ref":"Tint.RGB.html#from_hex/1-examples"},{"type":"function","title":"Tint.RGB.from_hex!/1","doc":"Builds a new RGB color from the given hex code. Raises when the given hex code\nis invalid.","ref":"Tint.RGB.html#from_hex!/1"},{"type":"function","title":"Examples - Tint.RGB.from_hex!/1","doc":"iex> Tint.RGB.from_hex!(\"#FF7F1E\")\n    #Tint.RGB<255,127,30 (#FF7F1E)>\n\n    iex> Tint.RGB.from_hex!(\"invalid\")\n    ** (ArgumentError) Invalid hex code: invalid","ref":"Tint.RGB.html#from_hex!/1-examples"},{"type":"function","title":"Tint.RGB.from_ratios/3","doc":"Builds a new RGB color from red, green and blue color ratios.","ref":"Tint.RGB.html#from_ratios/3"},{"type":"function","title":"Example - Tint.RGB.from_ratios/3","doc":"iex> Tint.RGB.from_ratios(1, 0.5, 0)\n    #Tint.RGB<255,128,0 (#FF8000)>","ref":"Tint.RGB.html#from_ratios/3-example"},{"type":"function","title":"Tint.RGB.from_tuple/1","doc":"Converts a tuple containing hue, saturation and value into a `Tint.RGB`\nstruct.","ref":"Tint.RGB.html#from_tuple/1"},{"type":"function","title":"Example - Tint.RGB.from_tuple/1","doc":"iex> Tint.RGB.from_tuple({255, 127, 30})\n    #Tint.RGB<255,127,30 (#FF7F1E)>","ref":"Tint.RGB.html#from_tuple/1-example"},{"type":"function","title":"Tint.RGB.grayish?/2","doc":"Determines whether the given color is grayish based on the distance of the\nred, green an blue channels of the color.\n\nAdditionally, you have to specify a tolerance that defines how far the min and\nthe max channels may be apart from each other. A tolerance of 0 means that the\ncolor has to be an exact grayscale color. A tolerance of 255 means that any\ncolor is regarded gray.","ref":"Tint.RGB.html#grayish?/2"},{"type":"function","title":"Tint.RGB.grayscale?/1","doc":"Determines whether the given color is a grayscale color which basically means\nthat the red, green and blue channels of the color have the same value.","ref":"Tint.RGB.html#grayscale?/1"},{"type":"function","title":"Tint.RGB.nearest_color/3","doc":"Finds the nearest color for the specified color using the given color palette\nand an optional distance algorithm.","ref":"Tint.RGB.html#nearest_color/3"},{"type":"function","title":"Tint.RGB.nearest_colors/4","doc":"Finds the n nearest colors for the specified color using the given color\npalette and an optional distance algorithm.","ref":"Tint.RGB.html#nearest_colors/4"},{"type":"function","title":"Tint.RGB.new/3","doc":"Builds a new RGB color from red, green and blue color parts. Please always\nuse this function to build a new RGB color.","ref":"Tint.RGB.html#new/3"},{"type":"function","title":"Examples - Tint.RGB.new/3","doc":"iex> Tint.RGB.new(0, 0, 0)\n    #Tint.RGB<0,0,0 (#000000)>\n\n    iex> Tint.RGB.new(255, 127, 30)\n    #Tint.RGB<255,127,30 (#FF7F1E)>\n\n    iex> Tint.RGB.new(256, -1, 0)\n    ** (Tint.OutOfRangeError) Value 256 is out of range [0,255]","ref":"Tint.RGB.html#new/3-examples"},{"type":"function","title":"Tint.RGB.to_hex/1","doc":"Converts a RGB color to a hex code.","ref":"Tint.RGB.html#to_hex/1"},{"type":"function","title":"Example - Tint.RGB.to_hex/1","doc":"iex> Tint.RGB.to_hex(%Tint.RGB{red: 255, green: 127, blue: 30})\n    \"#FF7F1E\"","ref":"Tint.RGB.html#to_hex/1-example"},{"type":"function","title":"Tint.RGB.to_ratios/1","doc":"Builds a tuple containing the ratios of the red, green and blue components of\na given color.","ref":"Tint.RGB.html#to_ratios/1"},{"type":"function","title":"Tint.RGB.to_tuple/1","doc":"Converts a RGB color into a tuple containing the red, green and blue channels.","ref":"Tint.RGB.html#to_tuple/1"},{"type":"function","title":"Example - Tint.RGB.to_tuple/1","doc":"iex> Tint.RGB.to_tuple(%Tint.RGB{red: 255, green: 127, blue: 30})\n    {255, 127, 30}","ref":"Tint.RGB.html#to_tuple/1-example"},{"type":"type","title":"Tint.RGB.t/0","doc":"","ref":"Tint.RGB.html#t:t/0"},{"type":"module","title":"Tint.XYZ","doc":"A color in the XYZ (CIE 1931) colorspace.","ref":"Tint.XYZ.html"},{"type":"function","title":"Tint.XYZ.new/3","doc":"Builds a new XYZ color using the lightness, a and b color channels.","ref":"Tint.XYZ.html#new/3"},{"type":"type","title":"Tint.XYZ.t/0","doc":"","ref":"Tint.XYZ.html#t:t/0"},{"type":"behaviour","title":"Tint.Distance","doc":"A module providing functions for color distance calculations and a behavior\nto implement custom distance algorithms.","ref":"Tint.Distance.html"},{"type":"function","title":"Tint.Distance.distance/3","doc":"Calculate the distance of two colors using the given distance algorithm.","ref":"Tint.Distance.html#distance/3"},{"type":"callback","title":"Tint.Distance.distance/3","doc":"Calculate the distance of two colors using the given options.","ref":"Tint.Distance.html#c:distance/3"},{"type":"function","title":"Tint.Distance.nearest_color/3","doc":"Gets the nearest color from the specified palette using the given distance\nalgorithm.","ref":"Tint.Distance.html#nearest_color/3"},{"type":"function","title":"Tint.Distance.nearest_colors/4","doc":"Gets the nearest n colors from the specified palette using the given distance\nalgorithm.","ref":"Tint.Distance.html#nearest_colors/4"},{"type":"type","title":"Tint.Distance.distance_algorithm/0","doc":"A distance calculation module that implements this very behavior or a function\nthat allows calculating the distance between two colors.","ref":"Tint.Distance.html#t:distance_algorithm/0"},{"type":"type","title":"Tint.Distance.distance_fun/0","doc":"A function that allows calculating the distance between two colors.","ref":"Tint.Distance.html#t:distance_fun/0"},{"type":"module","title":"Tint.Distance.CIEDE2000","doc":"A module that implements the CIEDE2000 color distance algorithm.\n(http://www2.ece.rochester.edu/~gsharma/ciede2000/ciede2000noteCRNA.pdf)","ref":"Tint.Distance.CIEDE2000.html"},{"type":"module","title":"Tint.Distance.Euclidean","doc":"A module that implements the Euclidean distance algorithm for RGB\ncolors. (https://en.wikipedia.org/wiki/Color_difference#Euclidean)","ref":"Tint.Distance.Euclidean.html"},{"type":"module","title":"Tint.Interval","doc":"An interval of two values with custom boundaries.","ref":"Tint.Interval.html"},{"type":"type","title":"Tint.Interval.bound/0","doc":"","ref":"Tint.Interval.html#t:bound/0"},{"type":"type","title":"Tint.Interval.t/0","doc":"","ref":"Tint.Interval.html#t:t/0"},{"type":"exception","title":"Tint.OutOfRangeError","doc":"An exception that is returned or raised when a color is built with values that\nare out of the permitted range of values.","ref":"Tint.OutOfRangeError.html"},{"type":"type","title":"Tint.OutOfRangeError.t/0","doc":"","ref":"Tint.OutOfRangeError.html#t:t/0"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2019 Tobias Casper\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Readme","doc":"# Tint\n\n[![Build](https://github.com/tlux/tint/actions/workflows/elixir.yml/badge.svg)](https://github.com/tlux/tint/actions/workflows/elixir.yml)\n[![Coverage Status](https://coveralls.io/repos/github/tlux/tint/badge.svg?branch=main)](https://coveralls.io/github/tlux/tint?branch=main)\n[![Module Version](https://img.shields.io/hexpm/v/tint.svg)](https://hex.pm/packages/tint)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/tint/)\n[![License](https://img.shields.io/hexpm/l/tint.svg)](https://github.com/tlux/tint/blob/main/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/tlux/tint.svg)](https://github.com/tlux/tint/commits/main)\n\nAn Elixir library allowing calculations with colors and conversions between\ndifferent colorspaces.\n\nCurrently supports the following color models:\n\n- [RGB](https://en.wikipedia.org/wiki/RGB_color_space)\n- [CMYK](https://en.wikipedia.org/wiki/CMYK_color_model)\n- [HSV](https://en.wikipedia.org/wiki/HSL_and_HSV)\n- L\\*a\\*b\\* ([CIELAB](https://en.wikipedia.org/wiki/CIELAB_color_space))\n- XYZ ([CIE 1931](https://en.wikipedia.org/wiki/CIE_1931_color_space))\n- [DIN99](https://de.wikipedia.org/wiki/DIN99-Farbraum)","ref":"readme.html"},{"type":"extras","title":"Prerequisites - Readme","doc":"- Elixir 1.14 or greater","ref":"readme.html#prerequisites"},{"type":"extras","title":"Installation - Readme","doc":"The package can be installed by adding `tint` to your list of dependencies in\n`mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tint, \"~> 1.2\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Readme","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"Colorspaces - Readme","doc":"##","ref":"readme.html#colorspaces"},{"type":"extras","title":"RGB - Readme","doc":"```elixir\niex> Tint.RGB.new(255, 0, 0)\n#Tint.RGB<255,0,0 (#FF0000)>\n```\n\nor\n\n```elixir\niex> import Tint.Sigil\n...> ~K[255, 0, 0]r\n#Tint.RGB<255,0,0 (#FF0000)>\n```\n\nUsing hex codes:\n\n```elixir\niex> Tint.RGB.from_hex(\"#FF0000\")\n{:ok, #Tint.RGB<255,0,0 (#FF0000)>}\n\niex> Tint.RGB.from_hex(\"#F00\")\n{:ok, #Tint.RGB<255,0,0 (#FF0000)>}\n\niex> Tint.RGB.from_hex(\"FF0000\")\n{:ok, #Tint.RGB<255,0,0 (#FF0000)>}\n\niex> Tint.RGB.from_hex!(\"F00\")\n#Tint.RGB<255,0,0 (#FF0000)>\n\niex> Tint.RGB.from_hex(\"invalid\")\n:error\n\niex> Tint.RGB.from_hex!(\"invalid\")\n** (ArgumentError) Invalid hex code: invalid\n```\n\nor\n\n```elixir\niex> import Tint.Sigil\n...> ~K[#FF0000]\n#Tint.RGB<255,0,0 (#FF0000)>\n```\n\nTo convert RGB colors back to hex codes:\n\n```elixir\niex> color = Tint.RGB.new(255, 0, 0)\n...> Tint.RGB.to_hex(color)\n\"#FF0000\"\n```\n\n##","ref":"readme.html#rgb"},{"type":"extras","title":"CMYK - Readme","doc":"```elixir\niex> Tint.CMYK.new(0.55, 0.26, 0.24, 0.65)\n#Tint.CMYK<55%,26%,24%,65%>\n```\n\nor\n\n```elixir\niex> import Tint.Sigil\n...> ~K[0.55, 0.26, 0.24, 0.65]c\n#Tint.CMYK<55%,26%,24%,65%>\n```\n\n##","ref":"readme.html#cmyk"},{"type":"extras","title":"HSV - Readme","doc":"```elixir\niex> Tint.HSV.new(25.8, 0.882, 1)\n#Tint.HSV<25.8°,88.2%,100%>\n```\n\nor\n\n```elixir\niex> import Tint.Sigil\n...> ~K[25.8, 0.882, 1]h\n#Tint.HSV<25.8°,88.2%,100%>\n```\n\n##","ref":"readme.html#hsv"},{"type":"extras","title":"CIELAB - Readme","doc":"```elixir\niex> Tint.Lab.new(53.2329, 80.1068, 67.2202)\n#Tint.Lab<53.2329,80.1068,67.2202>\n```\n\nor\n\n```elixir\niex> import Tint.Sigil\n...> ~K[53.2329, 80.1068, 67.2202]c\n#Tint.Lab<53.2329,80.1068,67.2202>\n```\n\n##","ref":"readme.html#cielab"},{"type":"extras","title":"DIN99 - Readme","doc":"```elixir\niex> Tint.DIN99.new(53.2329, 80.1068, 67.2202)\n#Tint.DIN99<53.2329,80.1068,67.2202>\n```\n\nor\n\n```elixir\niex> import Tint.Sigil\n...> ~K[53.2329, 80.1068, 67.2202]d\n#Tint.DIN99<53.2329,80.1068,67.2202>\n```\n\n#","ref":"readme.html#din99"},{"type":"extras","title":"Conversion - Readme","doc":"```elixir\niex> rgb = Tint.RGB.new(255, 0, 0)\n...> Tint.to_hsv(rgb)\n#Tint.HSV<0°,100%,100%>\n```\n\nThe complete list:\n\n```elixir\nTint.to_cmyk(color)\nTint.to_din99(color)\nTint.to_hsv(color)\nTint.to_lab(color)\nTint.to_rgb(color)\nTint.to_xyz(color)\n```\n\nAlternatively you can use `convert/2` and `convert!/2`:\n\n```elixir\nTint.convert(color, :rgb)\nTint.convert(color, Tint.RGB)\nTint.convert!(color, :hsv)\n```\n\nCurrently, only RGB can be converted to any other colorspace.\n\n#","ref":"readme.html#conversion"},{"type":"extras","title":"Color Distance - Readme","doc":"There are a couple of functions to calculate the distance between two colors.\n\n##","ref":"readme.html#color-distance"},{"type":"extras","title":"Euclidean Distance - Readme","doc":"The\n[Euclidean distance](https://en.wikipedia.org/wiki/Color_difference#Euclidean)\ncan be calculated on RGB colors. Calculating the Euclidean distance is very fast\nbut may not be very precise. If you want maximum precision use the CIEDE2000\nalgorithm.\n\n```elixir\niex> Tint.RGB.euclidean_distance(~K[#FFFFFF], ~K[#000000])\n441.6729559300637\n```\n\nYou can also define weights for the individual red, green and blue color\nchannels:\n\n```elixir\niex> Tint.RGB.euclidean_distance(~K[#FFFFFF], ~K[#000000], weights: {2, 4, 3})\n765.0\n```\n\nTo find the nearest color from a given palette:\n\n```elixir\niex> Tint.RGB.nearest_color(~K[#CC0000], [~K[#009900], ~K[#FF0000]])\n#Tint.RGB<255,0,0 (#FF0000)>\n```\n\n##","ref":"readme.html#euclidean-distance"},{"type":"extras","title":"CIEDE2000 - Readme","doc":"[CIEDE2000](https://en.wikipedia.org/wiki/Color_difference#CIEDE2000) is an\nalgorithm that operates on the CIELAB colorspace. It is very slow compared to\nthe Euclidean distance algorithm but it is optimized to human color perception.\n\n```elixir\niex> Tint.Lab.ciede2000_distance(~K[#FF0000], ~K[#000000])\n50.3905024704449\n```\n\nTo find the nearest color from a given palette:\n\n```elixir\niex> Tint.Lab.nearest_color(~K[#FF0000], [~K[#009900], ~K[#CC0000]])\n#Tint.RGB<204,0,0 (#CC0000)>\n```\n\n#","ref":"readme.html#ciede2000"},{"type":"extras","title":"Complementary Color - Readme","doc":"```elixir\niex> Tint.RGB.complementary_color(~K[#FF0000])\n#Tint.RGB<0,255,255 (#00FFFF)>\n```","ref":"readme.html#complementary-color"},{"type":"extras","title":"Docs - Readme","doc":"The API docs can be found at [HexDocs](https://hexdocs.pm/tint).","ref":"readme.html#docs"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}